package com.zsc.edu.gateway.modules.notice.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zsc.edu.gateway.framework.security.UserDetailsImpl;
import com.zsc.edu.gateway.modules.notice.entity.BulletinUser;
import com.zsc.edu.gateway.modules.notice.repo.BulletinUserRepository;
import com.zsc.edu.gateway.modules.notice.service.BulletinUserService;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;


/**
 * @author zhuang
 */
@AllArgsConstructor
@Service
public class BulletinUserServiceImpl extends ServiceImpl<BulletinUserRepository, BulletinUser> implements BulletinUserService {

    /**
     * 已读公告，每次已读自动获取用户id与公告id加入联表
     *
     * @param userDetails userDetails
     * @param id          id
     *                    return true
     */
    @Override
    public Boolean isRead(UserDetailsImpl userDetails, Long id) {
        if (id == null || userDetails.getId() == null) {
            throw new IllegalArgumentException("Bulletin ID and User ID cannot be null");
        }
        QueryWrapper<BulletinUser> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("bulletin_id", id)
                .eq("user_id", userDetails.getId());
        BulletinUser existingUser = getOne(queryWrapper);
        if (existingUser == null) {
            BulletinUser newUser = new BulletinUser();
            newUser.setBulletinId(id);
            newUser.setUserId(userDetails.getId());
            newUser.setIsRead(false);
            save(newUser);
        } else {
            UpdateWrapper<BulletinUser> updateWrapper = new UpdateWrapper<>();
            updateWrapper.eq("bulletin_id", id).eq("user_id", userDetails.getId()).set("is_read", false);
        }
        return true;
    }

    /**
     * 更新公告后修改已读状态
     *
     * @param id id
     */
    @Override
    public void toggleIsRead(Long id) {
        UpdateWrapper<BulletinUser> updateWrapper = new UpdateWrapper<>();
        updateWrapper.eq("bulletin_id", id).set("is_read", true);
    }

}
